You are viewing a plain text version of this content. The canonical link for it is here.
Posted to general@attic.apache.org by se...@apache.org on 2021/03/04 11:37:55 UTC

svn commit: r1887168 - /attic/site/xdocs/scripts/attic_filter.lua

Author: sebb
Date: Thu Mar  4 11:37:55 2021
New Revision: 1887168

URL: http://svn.apache.org/viewvc?rev=1887168&view=rev
Log:
Eagle needs special handling

Modified:
    attic/site/xdocs/scripts/attic_filter.lua

Modified: attic/site/xdocs/scripts/attic_filter.lua
URL: http://svn.apache.org/viewvc/attic/site/xdocs/scripts/attic_filter.lua?rev=1887168&r1=1887167&r2=1887168&view=diff
==============================================================================
--- attic/site/xdocs/scripts/attic_filter.lua (original)
+++ attic/site/xdocs/scripts/attic_filter.lua Thu Mar  4 11:37:55 2021
@@ -28,8 +28,8 @@ function output_filter(r)
         <a style='%s' href="https://attic.apache.org/projects/%s.html">
         Attic page</a>.
       </div>]]):format(sty1, name, sty2, host)
-    -- special processing needed for predictionio
-    if host == 'predictionio'
+    -- special processing needed for predictionio and eagle
+    if host == 'predictionio' or host == 'eagle'
     then
         coroutine.yield('')
     else
@@ -42,6 +42,10 @@ function output_filter(r)
         then    
             local output = bucket:gsub('<header>', '<header>'..div, 1)
             coroutine.yield(output)
+        elseif host == 'eagle'
+        then
+            local output = bucket:gsub('</nav>', '</nav>'..div, 1)
+            coroutine.yield(output)
         else
             coroutine.yield(bucket)
         end